@@ -8,9 +8,10 @@
 # later as published by the Python Software Foundation.
 # No warranty expressed or implied. See the file LICENSE.PSF-2 for details.
 
-""" Library to implement a well-behaved Unix daemon process
+""" Library to implement a well-behaved Unix daemon process.
 
-    This library implements PEP 3143: Standard daemon process library.
+    This library implements the well-behaved daemon specification of
+    :pep:`3143`, "Standard daemon process library".
 
     A well-behaved Unix daemon process is tricky to get right, but the
     required steps are much the same for every daemon program. A
@@ -27,9 +28,17 @@
         with daemon.DaemonContext():
             do_main_program()
 
+    Customisation of the steps to become a daemon is available by
+    setting options on the `DaemonContext` instance; see the
+    documentation for that class for each option.
+
     """
 
+import version
 from daemon import DaemonContext
 
 
-version = "1.4.4"
+_version = version.version
+_copyright = version.copyright
+_license = version.license
+_url = "http://pypi.python.org/pypi/python-daemon/"
