@@ -9,8 +9,8 @@
 # later as published by the Python Software Foundation.
 # No warranty expressed or implied. See the file LICENSE.PSF-2 for details.
 
-""" Unit test for pidlockfile module
-"""
+""" Unit test for pidlockfile module.
+    """
 
 import __builtin__
 import os
@@ -26,7 +26,7 @@ from daemon import pidlockfile
 
 
 def setup_pidlockfile_fixtures(testcase):
-    """ Set up common fixtures for PIDLockFile test cases """
+    """ Set up common fixtures for PIDLockFile test cases. """
 
     setup_pidfile_fixtures(testcase)
 
@@ -58,43 +58,43 @@ def setup_pidlockfile_fixtures(testcase):
 
 
 class PIDLockFile_TestCase(scaffold.TestCase):
-    """ Test cases for PIDLockFile class """
+    """ Test cases for PIDLockFile class. """
 
     def setUp(self):
         """ Set up test fixtures """
         setup_pidlockfile_fixtures(self)
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_instantiate(self):
-        """ New instance of PIDLockFile should be created """
+        """ New instance of PIDLockFile should be created. """
         instance = self.test_instance
         self.failUnlessIsInstance(instance, pidlockfile.PIDLockFile)
 
     def test_has_specified_path(self):
-        """ Should have specified path """
+        """ Should have specified path. """
         instance = self.test_instance
         expect_path = self.mock_pidfile_path
         self.failUnlessEqual(expect_path, instance.path)
 
 
 class PIDLockFile_read_pid_TestCase(scaffold.TestCase):
-    """ Test cases for PIDLockFile.read_pid method """
+    """ Test cases for PIDLockFile.read_pid method. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidlockfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_other
         self.pidfile_open_func = self.mock_pidfile_open_exist
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_gets_pid_via_read_pid_from_pidfile(self):
-        """ Should get PID via read_pid_from_pidfile """
+        """ Should get PID via read_pid_from_pidfile. """
         instance = self.test_instance
         test_pid = self.mock_other_pid
         expect_pid = test_pid
@@ -103,19 +103,19 @@ class PIDLockFile_read_pid_TestCase(scaffold.TestCase):
 
 
 class PIDLockFile_is_locked_TestCase(scaffold.TestCase):
-    """ Test cases for PIDLockFile.is_locked function """
+    """ Test cases for PIDLockFile.is_locked function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidlockfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_other
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_returns_true_if_pid_file(self):
-        """ Should return True if PID file exists """
+        """ Should return True if PID file exists. """
         instance = self.test_instance
         expect_result = True
         self.pidfile_path_exists_func = (lambda: True)
@@ -123,7 +123,7 @@ class PIDLockFile_is_locked_TestCase(scaffold.TestCase):
         self.failUnlessEqual(expect_result, result)
 
     def test_returns_false_if_no_pid_file(self):
-        """ Should return False if PID file does not exist """
+        """ Should return False if PID file does not exist. """
         instance = self.test_instance
         expect_result = False
         self.pidfile_path_exists_func = (lambda: False)
@@ -132,19 +132,19 @@ class PIDLockFile_is_locked_TestCase(scaffold.TestCase):
 
 
 class PIDLockFile_i_am_locking_TestCase(scaffold.TestCase):
-    """ Test cases for PIDLockFile.i_am_locking function """
+    """ Test cases for PIDLockFile.i_am_locking function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidlockfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_current
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_returns_false_if_no_pid_file(self):
-        """ Should return False if PID file does not exist """
+        """ Should return False if PID file does not exist. """
         instance = self.test_instance
         expect_result = False
         self.pidfile_path_exists_func = (lambda: False)
@@ -153,7 +153,7 @@ class PIDLockFile_i_am_locking_TestCase(scaffold.TestCase):
         self.failUnlessEqual(expect_result, result)
 
     def test_returns_false_if_pid_file_contains_bogus_pid(self):
-        """ Should return False if PID file contains a bogus PID """
+        """ Should return False if PID file contains a bogus PID. """
         instance = self.test_instance
         expect_result = False
         self.pidfile_path_exists_func = (lambda: True)
@@ -163,7 +163,7 @@ class PIDLockFile_i_am_locking_TestCase(scaffold.TestCase):
         self.failUnlessEqual(expect_result, result)
 
     def test_returns_false_if_pid_file_contains_different_pid(self):
-        """ Should return False if PID file contains a different PID """
+        """ Should return False if PID file contains a different PID. """
         instance = self.test_instance
         expect_result = False
         self.pidfile_path_exists_func = (lambda: True)
@@ -173,7 +173,7 @@ class PIDLockFile_i_am_locking_TestCase(scaffold.TestCase):
         self.failUnlessEqual(expect_result, result)
 
     def test_returns_true_if_pid_file_contains_current_pid(self):
-        """ Should return True if PID file contains the current PID """
+        """ Should return True if PID file contains the current PID. """
         instance = self.test_instance
         expect_result = True
         self.pidfile_path_exists_func = (lambda: True)
@@ -183,20 +183,20 @@ class PIDLockFile_i_am_locking_TestCase(scaffold.TestCase):
 
 
 class PIDLockFile_acquire_TestCase(scaffold.TestCase):
-    """ Test cases for PIDLockFile.acquire function """
+    """ Test cases for PIDLockFile.acquire function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidlockfile_fixtures(self)
         self.pidfile_path_exists_func = (lambda: False)
         self.pidfile_open_func = self.mock_pidfile_open_nonexist
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_raises_already_locked_if_file_exists(self):
-        """ Should raise AlreadyLocked error if PID file exists """
+        """ Should raise AlreadyLocked error if PID file exists. """
         instance = self.test_instance
         self.pidfile_path_exists_func = (lambda: True)
         expect_error = pidlockfile.AlreadyLocked
@@ -205,7 +205,7 @@ class PIDLockFile_acquire_TestCase(scaffold.TestCase):
             instance.acquire)
 
     def test_writes_pid_to_specified_file(self):
-        """ Should request writing current PID to specified file """
+        """ Should request writing current PID to specified file. """
         instance = self.test_instance
         pidfile_path = self.mock_pidfile_path
         expect_mock_output = """\
@@ -217,7 +217,7 @@ class PIDLockFile_acquire_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_raises_lock_failed_on_write_error(self):
-        """ Should raise LockFailed error if write fails """
+        """ Should raise LockFailed error if write fails. """
         instance = self.test_instance
         pidfile_path = self.mock_pidfile_path
         mock_error = OSError(errno.EBUSY, "Bad stuff", pidfile_path)
@@ -229,21 +229,21 @@ class PIDLockFile_acquire_TestCase(scaffold.TestCase):
 
 
 class PIDLockFile_release_TestCase(scaffold.TestCase):
-    """ Test cases for PIDLockFile.release function """
+    """ Test cases for PIDLockFile.release function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidlockfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_current
         self.pidfile_path_exists_func = (lambda: True)
         self.pidfile_open_func = self.mock_pidfile_open_exist
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_raises_not_locked_if_no_pid_file(self):
-        """ Should raise NotLocked error if PID file does not exist """
+        """ Should raise NotLocked error if PID file does not exist. """
         instance = self.test_instance
         self.pidfile_path_exists_func = (lambda: False)
         expect_error = pidlockfile.NotLocked
@@ -252,7 +252,7 @@ class PIDLockFile_release_TestCase(scaffold.TestCase):
             instance.release)
 
     def test_raises_not_my_lock_if_pid_file_not_locked_by_this_lock(self):
-        """ Should raise NotMyLock error if PID file not locked by me """
+        """ Should raise NotMyLock error if PID file not locked by me. """
         instance = self.test_instance
         self.mock_pidfile = self.mock_pidfile_other
         expect_error = pidlockfile.NotMyLock
@@ -261,7 +261,7 @@ class PIDLockFile_release_TestCase(scaffold.TestCase):
             instance.release)
 
     def test_removes_existing_pidfile(self):
-        """ Should request removal of specified PID file """
+        """ Should request removal of specified PID file. """
         instance = self.test_instance
         self.mock_pidfile = self.mock_pidfile_current
         pidfile_path = self.mock_pidfile_path
@@ -275,21 +275,21 @@ class PIDLockFile_release_TestCase(scaffold.TestCase):
 
 
 class PIDLockFile_break_lock_TestCase(scaffold.TestCase):
-    """ Test cases for PIDLockFile.break_lock function """
+    """ Test cases for PIDLockFile.break_lock function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidlockfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_other
         self.pidfile_path_exists_func = (lambda: True)
         self.pidfile_open_func = self.mock_pidfile_open_exist
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_returns_none_if_no_pid_file(self):
-        """ Should return None if PID file does not exist """
+        """ Should return None if PID file does not exist. """
         instance = self.test_instance
         self.pidfile_path_exists_func = (lambda: False)
         expect_result = None
@@ -297,7 +297,7 @@ class PIDLockFile_break_lock_TestCase(scaffold.TestCase):
         self.failUnlessEqual(expect_result, result)
 
     def test_removes_existing_pidfile(self):
-        """ Should request removal of specified PID file """
+        """ Should request removal of specified PID file. """
         instance = self.test_instance
         pidfile_path = self.mock_pidfile_path
         expect_mock_output = """\
@@ -310,7 +310,7 @@ class PIDLockFile_break_lock_TestCase(scaffold.TestCase):
 
 
 class FakeFileDescriptorStringIO(StringIO, object):
-    """ A StringIO class that fakes a file descriptor """
+    """ A StringIO class that fakes a file descriptor. """
 
     _fileno_generator = itertools.count()
 
@@ -324,7 +324,7 @@ class FakeFileDescriptorStringIO(StringIO, object):
 
 
 def setup_pidfile_fixtures(testcase):
-    """ Set up common fixtures for PID file test cases """
+    """ Set up common fixtures for PID file test cases. """
     testcase.mock_tracker = scaffold.MockTracker()
 
     testcase.mock_current_pid = 235
@@ -384,45 +384,45 @@ def setup_pidfile_fixtures(testcase):
 
 
 class pidfile_exists_TestCase(scaffold.TestCase):
-    """ Test cases for pidfile_exists function """
+    """ Test cases for pidfile_exists function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_other
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_returns_true_when_pidfile_exists(self):
-        """ Should return True when pidfile exists """
+        """ Should return True when pidfile exists. """
         self.pidfile_exists_func = (lambda p: True)
         result = pidlockfile.pidfile_exists(self.mock_pidfile_path)
         self.failUnless(result)
 
     def test_returns_false_when_no_pidfile_exists(self):
-        """ Should return False when pidfile does not exist """
+        """ Should return False when pidfile does not exist. """
         self.pidfile_exists_func = (lambda p: False)
         result = pidlockfile.pidfile_exists(self.mock_pidfile_path)
         self.failIf(result)
 
 
 class read_pid_from_pidfile_TestCase(scaffold.TestCase):
-    """ Test cases for read_pid_from_pidfile function """
+    """ Test cases for read_pid_from_pidfile function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_other
         self.pidfile_open_func = self.mock_pidfile_open_exist
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_opens_specified_filename(self):
-        """ Should attempt to open specified pidfile filename """
+        """ Should attempt to open specified pidfile filename. """
         pidfile_path = self.mock_pidfile_path
         expect_mock_output = """\
             Called __builtin__.open(%(pidfile_path)r, 'r')
@@ -432,7 +432,7 @@ class read_pid_from_pidfile_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_reads_pid_from_file(self):
-        """ Should read the PID from the specified file """
+        """ Should read the PID from the specified file. """
         pidfile_path = self.mock_pidfile_path
         expect_pid = self.mock_other_pid
         pid = pidlockfile.read_pid_from_pidfile(pidfile_path)
@@ -440,7 +440,7 @@ class read_pid_from_pidfile_TestCase(scaffold.TestCase):
         self.failUnlessEqual(expect_pid, pid)
 
     def test_returns_none_when_file_nonexist(self):
-        """ Should return None when the PID file does not exist """
+        """ Should return None when the PID file does not exist. """
         pidfile_path = self.mock_pidfile_path
         self.pidfile_open_func = self.mock_pidfile_open_nonexist
         pid = pidlockfile.read_pid_from_pidfile(pidfile_path)
@@ -449,10 +449,10 @@ class read_pid_from_pidfile_TestCase(scaffold.TestCase):
 
 
 class remove_existing_pidfile_TestCase(scaffold.TestCase):
-    """ Test cases for remove_existing_pidfile function """
+    """ Test cases for remove_existing_pidfile function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_current
         self.pidfile_open_func = self.mock_pidfile_open_exist
@@ -462,11 +462,11 @@ class remove_existing_pidfile_TestCase(scaffold.TestCase):
             tracker=self.mock_tracker)
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_removes_specified_filename(self):
-        """ Should attempt to remove specified PID file filename """
+        """ Should attempt to remove specified PID file filename. """
         pidfile_path = self.mock_pidfile_path
         expect_mock_output = """\
             Called os.remove(%(pidfile_path)r)
@@ -476,7 +476,7 @@ class remove_existing_pidfile_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_ignores_file_not_exist_error(self):
-        """ Should ignore error if file does not exist """
+        """ Should ignore error if file does not exist. """
         pidfile_path = self.mock_pidfile_path
         mock_error = OSError(errno.ENOENT, "Not there", pidfile_path)
         os.remove.mock_raises = mock_error
@@ -488,7 +488,7 @@ class remove_existing_pidfile_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_propagates_arbitrary_oserror(self):
-        """ Should propagate any OSError other than ENOENT """
+        """ Should propagate any OSError other than ENOENT. """
         pidfile_path = self.mock_pidfile_path
         mock_error = OSError(errno.EACCES, "Denied", pidfile_path)
         os.remove.mock_raises = mock_error
@@ -499,20 +499,20 @@ class remove_existing_pidfile_TestCase(scaffold.TestCase):
 
 
 class write_pid_to_pidfile_TestCase(scaffold.TestCase):
-    """ Test cases for write_pid_to_pidfile function """
+    """ Test cases for write_pid_to_pidfile function. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_pidfile_fixtures(self)
         self.mock_pidfile = self.mock_pidfile_current
         self.pidfile_open_func = self.mock_pidfile_open_nonexist
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_opens_specified_filename(self):
-        """ Should attempt to open specified PID file filename """
+        """ Should attempt to open specified PID file filename. """
         pidfile_path = self.mock_pidfile_path
         expect_mock_output = """\
             Called __builtin__.open(%(pidfile_path)r, 'w')
@@ -523,7 +523,7 @@ class write_pid_to_pidfile_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_writes_pid_to_file(self):
-        """ Should write the current PID to the specified file """
+        """ Should write the current PID to the specified file. """
         pidfile_path = self.mock_pidfile_path
         expect_line = "%(mock_current_pid)d\n" % vars(self)
         pidlockfile.write_pid_to_pidfile(pidfile_path)
