@@ -9,8 +9,8 @@
 # later as published by the Python Software Foundation.
 # No warranty expressed or implied. See the file LICENSE.PSF-2 for details.
 
-""" Unit test for runner module
-"""
+""" Unit test for runner module.
+    """
 
 import __builtin__
 import os
@@ -36,7 +36,7 @@ from daemon import runner
 
 
 def setup_runner_fixtures(testcase):
-    """ Set up common test fixtures for DaemonRunner test case """
+    """ Set up common test fixtures for DaemonRunner test case. """
     testcase.mock_tracker = scaffold.MockTracker()
 
     setup_pidfile_fixtures(testcase)
@@ -120,10 +120,10 @@ def setup_runner_fixtures(testcase):
 
 
 class DaemonRunner_TestCase(scaffold.TestCase):
-    """ Test cases for DaemonRunner class """
+    """ Test cases for DaemonRunner class. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_runner_fixtures(self)
         self.mock_tracker.clear()
 
@@ -134,15 +134,15 @@ class DaemonRunner_TestCase(scaffold.TestCase):
         self.test_instance = runner.DaemonRunner(self.test_app)
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_instantiate(self):
-        """ New instance of DaemonRunner should be created """
+        """ New instance of DaemonRunner should be created. """
         self.failUnlessIsInstance(self.test_instance, runner.DaemonRunner)
 
     def test_parses_commandline_args(self):
-        """ Should parse commandline arguments """
+        """ Should parse commandline arguments. """
         expect_mock_output = """\
             Called runner.DaemonRunner.parse_args()
             ...
@@ -150,11 +150,11 @@ class DaemonRunner_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_has_specified_app(self):
-        """ Should have specified application object """
+        """ Should have specified application object. """
         self.failUnlessIs(self.test_app, self.test_instance.app)
 
     def test_error_when_pidfile_path_not_string(self):
-        """ Should raise ValueError when PID file path not a string """
+        """ Should raise ValueError when PID file path not a string. """
         pidfile_path = object()
         self.test_app.pidfile_path = pidfile_path
         expect_error = ValueError
@@ -163,7 +163,7 @@ class DaemonRunner_TestCase(scaffold.TestCase):
             runner.DaemonRunner, self.test_app)
 
     def test_error_when_pidfile_path_not_absolute(self):
-        """ Should raise ValueError when PID file path not absolute """
+        """ Should raise ValueError when PID file path not absolute. """
         pidfile_path = "foo/bar.pid"
         self.test_app.pidfile_path = pidfile_path
         expect_error = ValueError
@@ -172,7 +172,7 @@ class DaemonRunner_TestCase(scaffold.TestCase):
             runner.DaemonRunner, self.test_app)
 
     def test_creates_pidlockfile(self):
-        """ Should create a PIDLockFile with the specified PID file path """
+        """ Should create a PIDLockFile with the specified PID file path. """
         pidfile_path = self.mock_pidfile_path
         expect_mock_output = """\
             ...
@@ -182,60 +182,60 @@ class DaemonRunner_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
  
     def test_has_created_pidfile(self):
-        """ Should have new PID lock file as `pidfile` attribute """
+        """ Should have new PID lock file as `pidfile` attribute. """
         expect_pidfile = self.mock_pidlockfile
         instance = self.test_instance
         self.failUnlessIs(
             expect_pidfile, instance.pidfile)
  
     def test_daemon_context_has_created_pidfile(self):
-        """ DaemonContext component should have new PID lock file """
+        """ DaemonContext component should have new PID lock file. """
         expect_pidfile = self.mock_pidlockfile
         daemon_context = self.test_instance.daemon_context
         self.failUnlessIs(
             expect_pidfile, daemon_context.pidfile)
 
     def test_daemon_context_has_specified_stdin_stream(self):
-        """ DaemonContext component should have specified stdin file """
+        """ DaemonContext component should have specified stdin file. """
         test_app = self.test_app
         expect_file = self.stream_files_by_name['stdin']
         daemon_context = self.test_instance.daemon_context
         self.failUnlessEqual(expect_file, daemon_context.stdin)
 
     def test_daemon_context_has_stdin_in_read_mode(self):
-        """ DaemonContext component should open stdin file for read """
+        """ DaemonContext component should open stdin file for read. """
         expect_mode = 'r'
         daemon_context = self.test_instance.daemon_context
         self.failUnlessIn(daemon_context.stdin.mode, expect_mode)
 
     def test_daemon_context_has_specified_stdout_stream(self):
-        """ DaemonContext component should have specified stdout file """
+        """ DaemonContext component should have specified stdout file. """
         test_app = self.test_app
         expect_file = self.stream_files_by_name['stdout']
         daemon_context = self.test_instance.daemon_context
         self.failUnlessEqual(expect_file, daemon_context.stdout)
 
     def test_daemon_context_has_stdout_in_append_mode(self):
-        """ DaemonContext component should open stdout file for append """
+        """ DaemonContext component should open stdout file for append. """
         expect_mode = 'w+'
         daemon_context = self.test_instance.daemon_context
         self.failUnlessIn(daemon_context.stdout.mode, expect_mode)
 
     def test_daemon_context_has_specified_stderr_stream(self):
-        """ DaemonContext component should have specified stderr file """
+        """ DaemonContext component should have specified stderr file. """
         test_app = self.test_app
         expect_file = self.stream_files_by_name['stderr']
         daemon_context = self.test_instance.daemon_context
         self.failUnlessEqual(expect_file, daemon_context.stderr)
 
     def test_daemon_context_has_stderr_in_append_mode(self):
-        """ DaemonContext component should open stderr file for append """
+        """ DaemonContext component should open stderr file for append. """
         expect_mode = 'w+'
         daemon_context = self.test_instance.daemon_context
         self.failUnlessIn(daemon_context.stderr.mode, expect_mode)
 
     def test_daemon_context_has_stderr_with_no_buffering(self):
-        """ DaemonContext component should open stderr file unbuffered """
+        """ DaemonContext component should open stderr file unbuffered. """
         expect_buffering = 0
         daemon_context = self.test_instance.daemon_context
         self.failUnlessEqual(
@@ -243,18 +243,18 @@ class DaemonRunner_TestCase(scaffold.TestCase):
 
 
 class DaemonRunner_usage_exit_TestCase(scaffold.TestCase):
-    """ Test cases for DaemonRunner.usage_exit method """
+    """ Test cases for DaemonRunner.usage_exit method. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_runner_fixtures(self)
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_raises_system_exit(self):
-        """ Should raise SystemExit exception """
+        """ Should raise SystemExit exception. """
         instance = self.test_instance
         argv = [self.test_program_path]
         self.failUnlessRaises(
@@ -262,7 +262,7 @@ class DaemonRunner_usage_exit_TestCase(scaffold.TestCase):
             instance._usage_exit, argv)
 
     def test_message_follows_conventional_format(self):
-        """ Should emit a conventional usage message """
+        """ Should emit a conventional usage message. """
         instance = self.test_instance
         progname = self.test_program_name
         argv = [self.test_program_path]
@@ -277,10 +277,10 @@ class DaemonRunner_usage_exit_TestCase(scaffold.TestCase):
 
 
 class DaemonRunner_parse_args_TestCase(scaffold.TestCase):
-    """ Test cases for DaemonRunner.parse_args method """
+    """ Test cases for DaemonRunner.parse_args method. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_runner_fixtures(self)
         self.mock_tracker.clear()
         scaffold.mock(
@@ -289,11 +289,11 @@ class DaemonRunner_parse_args_TestCase(scaffold.TestCase):
             tracker=self.mock_tracker)
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_emits_usage_message_if_insufficient_args(self):
-        """ Should emit a usage message and exit if too few arguments """
+        """ Should emit a usage message and exit if too few arguments. """
         instance = self.test_instance
         argv = [self.test_program_path]
         expect_mock_output = """\
@@ -306,7 +306,7 @@ class DaemonRunner_parse_args_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_emits_usage_message_if_unknown_action_arg(self):
-        """ Should emit a usage message and exit if unknown action """
+        """ Should emit a usage message and exit if unknown action. """
         instance = self.test_instance
         progname = self.test_program_name
         argv = [self.test_program_path, 'bogus']
@@ -320,7 +320,7 @@ class DaemonRunner_parse_args_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_should_parse_system_argv_by_default(self):
-        """ Should parse sys.argv by default """
+        """ Should parse sys.argv by default. """
         instance = self.test_instance
         expect_action = 'start'
         argv = self.valid_argv_params['start']
@@ -332,7 +332,7 @@ class DaemonRunner_parse_args_TestCase(scaffold.TestCase):
         self.failUnlessEqual(expect_action, instance.action)
 
     def test_sets_action_from_first_argument(self):
-        """ Should set action from first commandline argument """
+        """ Should set action from first commandline argument. """
         instance = self.test_instance
         for name, argv in self.valid_argv_params.items():
             expect_action = name
@@ -341,18 +341,18 @@ class DaemonRunner_parse_args_TestCase(scaffold.TestCase):
 
 
 class DaemonRunner_do_action_TestCase(scaffold.TestCase):
-    """ Test cases for DaemonRunner.do_action method """
+    """ Test cases for DaemonRunner.do_action method. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_runner_fixtures(self)
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_raises_error_if_unknown_action(self):
-        """ Should emit a usage message and exit if too few arguments """
+        """ Should emit a usage message and exit if too few arguments. """
         instance = self.test_instance
         instance.action = 'bogus'
         expect_error = ValueError
@@ -362,10 +362,10 @@ class DaemonRunner_do_action_TestCase(scaffold.TestCase):
 
 
 class DaemonRunner_do_action_start_TestCase(scaffold.TestCase):
-    """ Test cases for DaemonRunner.do_action method, action 'start' """
+    """ Test cases for DaemonRunner.do_action method, action 'start'. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_runner_fixtures(self)
         self.mock_tracker.clear()
 
@@ -376,11 +376,11 @@ class DaemonRunner_do_action_start_TestCase(scaffold.TestCase):
         self.mock_pidlockfile.read_pid.mock_returns = None
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_aborts_if_pidfile_locked(self):
-        """ Should raise SystemExit if PID file is locked """
+        """ Should raise SystemExit if PID file is locked. """
         instance = self.test_instance
         self.mock_pidlockfile.is_locked.mock_returns = True
         self.mock_pidlockfile.i_am_locking.mock_returns = False
@@ -397,7 +397,7 @@ class DaemonRunner_do_action_start_TestCase(scaffold.TestCase):
         self.failUnlessIn(exc.message, pidfile_path)
 
     def test_breaks_lock_if_no_such_process(self):
-        """ Should request breaking lock if PID file process is not running """
+        """ Should request breaking lock if PID file process is not running. """
         instance = self.test_instance
         self.mock_pidlockfile.is_locked.mock_returns = True
         self.mock_pidlockfile.i_am_locking.mock_returns = False
@@ -418,7 +418,7 @@ class DaemonRunner_do_action_start_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_requests_daemon_context_open(self):
-        """ Should request the daemon context to open """
+        """ Should request the daemon context to open. """
         instance = self.test_instance
         expect_mock_output = """\
             ...
@@ -429,7 +429,7 @@ class DaemonRunner_do_action_start_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_emits_start_message_to_stderr(self):
-        """ Should emit start message to stderr """
+        """ Should emit start message to stderr. """
         instance = self.test_instance
         current_pid = self.mock_current_pid
         expect_stderr = """\
@@ -440,7 +440,7 @@ class DaemonRunner_do_action_start_TestCase(scaffold.TestCase):
             expect_stderr, self.mock_stderr.getvalue())
 
     def test_requests_app_run(self):
-        """ Should request the application to run """
+        """ Should request the application to run. """
         instance = self.test_instance
         expect_mock_output = """\
             ...
@@ -451,10 +451,10 @@ class DaemonRunner_do_action_start_TestCase(scaffold.TestCase):
 
 
 class DaemonRunner_do_action_stop_TestCase(scaffold.TestCase):
-    """ Test cases for DaemonRunner.do_action method, action 'stop' """
+    """ Test cases for DaemonRunner.do_action method, action 'stop'. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_runner_fixtures(self)
         self.mock_tracker.clear()
 
@@ -465,11 +465,11 @@ class DaemonRunner_do_action_stop_TestCase(scaffold.TestCase):
         self.mock_pidlockfile.read_pid.mock_returns = self.mock_other_pid
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_aborts_if_pidfile_not_locked(self):
-        """ Should report failure and exit if PID file is not locked """
+        """ Should report failure and exit if PID file is not locked. """
         instance = self.test_instance
         self.mock_pidlockfile.is_locked.mock_returns = False
         self.mock_pidlockfile.i_am_locking.mock_returns = False
@@ -487,7 +487,7 @@ class DaemonRunner_do_action_stop_TestCase(scaffold.TestCase):
         self.failUnlessIn(exc.message, pidfile_path)
 
     def test_breaks_lock_if_pidfile_lock_stale(self):
-        """ Should break lock if PID file lock is stale """
+        """ Should break lock if PID file lock is stale. """
         instance = self.test_instance
         pidfile_path = self.mock_pidfile_path
         test_pid = self.mock_other_pid
@@ -504,7 +504,7 @@ class DaemonRunner_do_action_stop_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_sends_terminate_signal_to_process_from_pidfile(self):
-        """ Should send SIGTERM to the daemon process """
+        """ Should send SIGTERM to the daemon process. """
         instance = self.test_instance
         test_pid = self.mock_other_pid
         expect_signal = signal.SIGTERM
@@ -517,7 +517,7 @@ class DaemonRunner_do_action_stop_TestCase(scaffold.TestCase):
         self.failUnlessMockCheckerMatch(expect_mock_output)
 
     def test_aborts_if_cannot_send_signal_to_process(self):
-        """ Should raise SystemExit if cannot send signal to daemon process """
+        """ Should raise SystemExit if cannot send signal to daemon process. """
         instance = self.test_instance
         test_pid = self.mock_other_pid
         pidfile_path = self.mock_pidfile_path
@@ -530,21 +530,21 @@ class DaemonRunner_do_action_stop_TestCase(scaffold.TestCase):
 
 
 class DaemonRunner_do_action_restart_TestCase(scaffold.TestCase):
-    """ Test cases for DaemonRunner.do_action method, action 'restart' """
+    """ Test cases for DaemonRunner.do_action method, action 'restart'. """
 
     def setUp(self):
-        """ Set up test fixtures """
+        """ Set up test fixtures. """
         setup_runner_fixtures(self)
         self.mock_tracker.clear()
 
         self.test_instance.action = 'restart'
 
     def tearDown(self):
-        """ Tear down test fixtures """
+        """ Tear down test fixtures. """
         scaffold.mock_restore()
 
     def test_requests_stop_then_start(self):
-        """ Should request stop, then start """
+        """ Should request stop, then start. """
         instance = self.test_instance
         scaffold.mock(
             "daemon.runner.DaemonRunner._start",
